@@ -24,12 +24,12 @@ func init() {
 	RegisterRule(rule)
 }
 
-func engineChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, opts Options) *Note {
+func engineChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, opts *Options) *Note {
 	if opts.IsAllowed("engine", table.Engine) {
 		return nil
 	}
 	re := regexp.MustCompile(fmt.Sprintf(`(?i)ENGINE\s*=?\s*%s`, table.Engine))
-	message := fmt.Sprintf("Table %s is using storage engine %s, which is not configured to be permitted.", table.Name, table.Engine)
+	message := fmt.Sprintf("Table %s is using storage engine %s, which is not configured to be permitted.", tengo.EscapeIdentifier(table.Name), table.Engine)
 	allowedEngines := opts.AllowList("engine")
 	if len(allowedEngines) == 1 {
 		message = fmt.Sprintf("%s Only the %s storage engine is listed in option allow-engine.", message, allowedEngines[0])
