@@ -16,7 +16,7 @@ func init() {
 	})
 }
 
-func hasEnumChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ Options) []Note {
+func hasEnumChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ *Options) []Note {
 	results := make([]Note, 0)
 	for _, col := range table.Columns {
 		if strings.HasPrefix(col.TypeInDB, "enum") || strings.HasPrefix(col.TypeInDB, "set") {
@@ -26,8 +26,8 @@ func hasEnumChecker(table *tengo.Table, createStatement string, _ *tengo.Schema,
 				typeWithoutValues = "set"
 			}
 			message := fmt.Sprintf(
-				"Column %s of table %s is using type %s. This data type can cause operational difficulties due to lack of flexibility, and may be prone to subtle errors.",
-				col.Name, table.Name, typeWithoutValues,
+				"Column %s of %s is using type %s. This data type can cause operational difficulties due to lack of flexibility, and may be prone to subtle errors.",
+				col.Name, table.ObjectKey(), typeWithoutValues,
 			)
 			results = append(results, Note{
 				LineOffset: FindColumnLineOffset(col, createStatement),
