@@ -28,13 +28,14 @@ func (s *TengoIntegrationSuite) Setup(backend string) (err error) {
 		Name:         fmt.Sprintf("skeema-test-%s", ContainerNameForImage(backend)),
 		Image:        backend,
 		RootPassword: "fakepw",
+		DataTmpfs:    true,
 	}
 	s.d, err = GetOrCreateDockerizedInstance(opts)
 	return err
 }
 
 func (s *TengoIntegrationSuite) Teardown(backend string) error {
-	return s.d.Stop()
+	return SkeemaTestContainerCleanup(s.d)
 }
 
 func (s *TengoIntegrationSuite) BeforeTest(backend string) error {
@@ -229,10 +230,14 @@ func aTableForFlavor(flavor Flavor, nextAutoInc uint64) Table {
 	if flavor.MinMySQL(8, 0, 29) || flavor.MinMariaDB(10, 6) {
 		// MySQL 8.0.29+ and MariaDB 10.6+ report the legacy utf8 charset as utf8mb3.
 		// MySQL 8.0.30+ and MariaDB 10.6+ also update collation names accordingly.
+		// MariaDB 11.5+ changes utf8mb3's default collation to utf8mb3_uca1400_ai_ci.
 		utf8mb3 = "utf8mb3"
 		if !flavor.IsMySQL(8, 0, 29) {
 			utf8mb3DefaultCollation = "utf8mb3_general_ci"
 		}
+		if flavor.MinMariaDB(11, 5) {
+			utf8mb3DefaultCollation = "utf8mb3_uca1400_ai_ci"
+		}
 	}
 	lastUpdateCol := &Column{
 		Name:     "last_update",
