@@ -110,7 +110,7 @@ func (s WorkspaceIntegrationSuite) TestTempSchemaCleanupDrop(t *testing.T) {
 // keys and metadata locking. This is necessary because MySQL 8.0 extends
 // metadata locks across both sides of an FK, which can be problematic with DDL.
 func (s WorkspaceIntegrationSuite) TestTempSchemaCrossDBFK(t *testing.T) {
-	if !s.d.Flavor().Min(tengo.FlavorMySQL80) {
+	if !s.d.Flavor().MinMySQL(8) {
 		t.Skip("Test only relevant for flavors that extend metadata locks across FK relations")
 	}
 
